from setuptools import setup
import py2exe

setup(console=['Panda3DToolsGUI.py'])
